----------------------------------------------------------------
--Create SAR tables, aliases, constraints, and indexes.
----------------------------------------------------------------
--Description:
--Create SAR tables, aliases, constraints, and indexes.
--This script is a template for creating the bufferpools
--required for the 'base' AML Knowledge Center schema.
--
--This script must be run as a user with SYSADM or DBADM privileges.
--
--------------------------------------------------------------
--------------------------------------------------------------


CREATE TABLE AMLCTR.ACTIVITY_TYPE_CODES
(
	ACTIVITY_TYPE  CHAR(1)  NOT NULL ,
	SAR_TYPE  CHAR(2)  NOT NULL ,
	DESCRIPTION  VARCHAR(40)  NOT NULL ,
	PRIMARY KEY ( ACTIVITY_TYPE,SAR_TYPE)
)

;


COMMENT ON TABLE AMLCTR.ACTIVITY_TYPE_CODES IS 'Suspicious activity type codes'
;


COMMENT ON COLUMN AMLCTR.ACTIVITY_TYPE_CODES.ACTIVITY_TYPE IS 'Suspicious Activity type codes'
;


COMMENT ON COLUMN AMLCTR.ACTIVITY_TYPE_CODES.SAR_TYPE IS 'Type of SAR (i.e. banking, brokerage)'
;


COMMENT ON COLUMN AMLCTR.ACTIVITY_TYPE_CODES.DESCRIPTION IS 'Long text description of the suspicious activity'
;


CREATE TABLE AMLCTR.BATCH_SEQ
(
	SAR_ID  NUMERIC(15,0)  NOT NULL ,
	SEGMENT_ID  VARCHAR(128)  NOT NULL  DEFAULT user,
	SEQ_NUMBER  CHAR(18)  NOT NULL ,
	FILE_CREATION_DATE TIMESTAMP  ,
	BATCH_FILE_NAME  VARCHAR(40)  ,
	UPDATE_DATE  CHAR(18)  NOT NULL ,
	UPDATE_ID  VARCHAR(35)  ,
	PRIMARY KEY (SAR_ID,SEGMENT_ID)
)
;


COMMENT ON TABLE AMLCTR.BATCH_SEQ IS 'The BATCH_SEQ table is used to hold electronic filing related information.  This table is not populated directly by end-user activity,'
;


COMMENT ON COLUMN AMLCTR.BATCH_SEQ.SAR_ID IS 'System generated primary key for SAR'
;


COMMENT ON COLUMN AMLCTR.BATCH_SEQ.SEQ_NUMBER IS 'Transaction sequence number.'
;


COMMENT ON COLUMN AMLCTR.BATCH_SEQ.FILE_CREATION_DATE IS 'Date batch file was created.'
;


COMMENT ON COLUMN AMLCTR.BATCH_SEQ.BATCH_FILE_NAME IS 'Name of the batch file.'
;


COMMENT ON COLUMN AMLCTR.BATCH_SEQ.UPDATE_DATE IS 'Date the SAR was last updated'
;


COMMENT ON COLUMN AMLCTR.BATCH_SEQ.UPDATE_ID IS 'ID of user last updating  SAR'
;


CREATE TABLE AMLCTR.BRANCH
(
	INSTITUTION_ID  NUMERIC(10,0)  NOT NULL ,
	BRANCH_SEQ  NUMERIC(10,0)  NOT NULL ,
	SEGMENT_ID  VARCHAR(128)  NOT NULL  DEFAULT user,
	BRANCH_ADDRESS  VARCHAR(35)  ,
	BRANCH_CITY  VARCHAR(25)  ,
	BRANCH_STATE  CHAR(2)  ,
	BRANCH_ZIP  CHAR(9)  ,
	BRANCH_CODE  CHAR(7)  ,
	PRIMARY KEY (INSTITUTION_ID,BRANCH_SEQ,SEGMENT_ID)
)
;


COMMENT ON TABLE AMLCTR.BRANCH IS 'The BRANCH table contains branch addresses associated with each institution.'
;


COMMENT ON COLUMN AMLCTR.BRANCH.INSTITUTION_ID IS 'Unique identifier for the financial institution'
;


COMMENT ON COLUMN AMLCTR.BRANCH.BRANCH_SEQ IS 'System generated sequence number'
;


COMMENT ON COLUMN AMLCTR.BRANCH.BRANCH_ADDRESS IS 'Branch street address'
;


COMMENT ON COLUMN AMLCTR.BRANCH.BRANCH_CITY IS 'Branch city'
;


COMMENT ON COLUMN AMLCTR.BRANCH.BRANCH_STATE IS 'Branch state'
;


COMMENT ON COLUMN AMLCTR.BRANCH.BRANCH_ZIP IS 'Branch ZIP code'
;


COMMENT ON COLUMN AMLCTR.BRANCH.BRANCH_CODE IS 'Branch code'
;


CREATE TABLE AMLCTR.COUNTRY_CODES
(
	COUNTRY  CHAR(2)  NOT NULL ,
	SAR_TYPE  CHAR(2)  NOT NULL ,
	COUNTRY_NAME  VARCHAR(45)  ,
	PRIMARY KEY (COUNTRY,SAR_TYPE)
)
;


COMMENT ON TABLE AMLCTR.COUNTRY_CODES IS 'Country code table'
;


COMMENT ON COLUMN AMLCTR.COUNTRY_CODES.COUNTRY IS 'Country code'
;


COMMENT ON COLUMN AMLCTR.COUNTRY_CODES.COUNTRY_NAME IS 'Country Name'
;





CREATE TABLE AMLCTR.ENFORCEMENT_CODES
(
	ENFORCEMENT  CHAR(1)  NOT NULL ,
	SAR_TYPE  CHAR(2)  NOT NULL ,
	DESCRIPTION  VARCHAR(40)  NOT NULL 
)
PRIMARY INDEX ( SAR_TYPE )
;


COMMENT ON TABLE AMLCTR.ENFORCEMENT_CODES IS 'Law enforcement agency codes'
;


COMMENT ON COLUMN AMLCTR.ENFORCEMENT_CODES.ENFORCEMENT IS 'Law enforcement agency code'
;


COMMENT ON COLUMN AMLCTR.ENFORCEMENT_CODES.SAR_TYPE IS 'Type of SAR (i.e. banking, brokerage)'
;


COMMENT ON COLUMN AMLCTR.ENFORCEMENT_CODES.DESCRIPTION IS 'Long text description of law enforcement agency'
;


ALTER TABLE AMLCTR.ENFORCEMENT_CODES
	ADD CONSTRAINT  XPKE_22 PRIMARY KEY (ENFORCEMENT,SAR_TYPE)
;


CREATE TABLE AMLCTR.GOVT_ID_CODES
(
	GOVT_ID  CHAR(1)  NOT NULL ,
	SAR_TYPE  CHAR(2)  NOT NULL ,
	DESCRIPTION  VARCHAR(40)  NOT NULL ,
	PRIMARY KEY (GOVT_ID,SAR_TYPE)
)
;


COMMENT ON TABLE AMLCTR.GOVT_ID_CODES IS 'Code table containing government identification codes (i.e. driver''s license)'
;


COMMENT ON COLUMN AMLCTR.GOVT_ID_CODES.GOVT_ID IS 'ID value taken from SAR form to represent different forms of identification for suspect'
;


COMMENT ON COLUMN AMLCTR.GOVT_ID_CODES.SAR_TYPE IS 'Type of SAR (i.e. banking, brokerage)'
;


COMMENT ON COLUMN AMLCTR.GOVT_ID_CODES.DESCRIPTION IS 'Long text description of ID types'
;


CREATE TABLE AMLCTR.INSIDE_RELATIONSHIP_CODES
(
	INSIDE_RELATIONSHIP  CHAR(2)  NOT NULL ,
	SAR_TYPE  CHAR(2)  NOT NULL ,
	DESCRIPTION  VARCHAR(40)  NOT NULL 
)
PRIMARY INDEX ( SAR_TYPE )
;


COMMENT ON TABLE AMLCTR.INSIDE_RELATIONSHIP_CODES IS 'Code table for inside relationship codes'
;


COMMENT ON COLUMN AMLCTR.INSIDE_RELATIONSHIP_CODES.INSIDE_RELATIONSHIP IS 'Insider relationship code'
;


COMMENT ON COLUMN AMLCTR.INSIDE_RELATIONSHIP_CODES.SAR_TYPE IS 'Type of SAR (i.e. banking, brokerage)
'
;


COMMENT ON COLUMN AMLCTR.INSIDE_RELATIONSHIP_CODES.DESCRIPTION IS 'Long text description of the inside relationship'
;


ALTER TABLE AMLCTR.INSIDE_RELATIONSHIP_CODES
	ADD CONSTRAINT  XPKE_18 PRIMARY KEY (INSIDE_RELATIONSHIP,SAR_TYPE)
;


CREATE TABLE AMLCTR.INSTITUTION
(
	INSTITUTION_ID  NUMERIC(10,0)  NOT NULL ,
	SEGMENT_ID  VARCHAR(128)  NOT NULL  DEFAULT user,
	NAME  VARCHAR(35)  ,
	EIN  CHAR(9)  ,
	ADDRESS  VARCHAR(35)  ,
	CITY  VARCHAR(25)  ,
	STATE  CHAR(2)  ,
	ZIP  CHAR(9)  ,
	PRIMARY_REGULATOR  CHAR(1)  ,
	CEN_REG_NBR  CHAR(11)  ,
	SEC_ID  CHAR(9)  ,
	NFA_ID  CHAR(8)  ,
	TYPE_INSTITUTION  VARCHAR(27)  ,
	CONTACT_LNAME  VARCHAR(20)  ,
	CONTACT_FNAME  VARCHAR(20)  ,
	CONTACT_MI  CHAR(1)  ,
	CONTACT_TITLE  VARCHAR(25)  ,
	CONTACT_WORK_PHONE  CHAR(10)  ,
	TRANSMITTER_FLAG  CHAR(1)  ,
	TRANSMITTER_CONTROL_CODE  CHAR(8),
	PRIMARY KEY ( INSTITUTION_ID, SEGMENT_ID )
)
;


COMMENT ON TABLE AMLCTR.INSTITUTION IS 'INSTITUTION holds the names and address of financial instituions and their primary contacts.'
;


COMMENT ON COLUMN AMLCTR.INSTITUTION.INSTITUTION_ID IS 'Unique identifier for the financial institution'
;


COMMENT ON COLUMN AMLCTR.INSTITUTION.NAME IS 'Financial institution name'
;


COMMENT ON COLUMN AMLCTR.INSTITUTION.EIN IS 'Employer identification number'
;


COMMENT ON COLUMN AMLCTR.INSTITUTION.ADDRESS IS 'Institution street address'
;


COMMENT ON COLUMN AMLCTR.INSTITUTION.CITY IS 'Institution City'
;


COMMENT ON COLUMN AMLCTR.INSTITUTION.STATE IS 'Institution City'
;


COMMENT ON COLUMN AMLCTR.INSTITUTION.ZIP IS 'Institution ZIP Code'
;


COMMENT ON COLUMN AMLCTR.INSTITUTION.PRIMARY_REGULATOR IS 'Institution''s primary government regulator'
;


COMMENT ON COLUMN AMLCTR.INSTITUTION.CEN_REG_NBR IS 'FIN101 ONLY. Central Registration Depository Number.'
;


COMMENT ON COLUMN AMLCTR.INSTITUTION.SEC_ID IS 'FIN101 ONLY.  SEC ID Number'
;


COMMENT ON COLUMN AMLCTR.INSTITUTION.NFA_ID IS 'FIN101 ONLY.  National Futures Association ID Number.'
;


COMMENT ON COLUMN AMLCTR.INSTITUTION.TYPE_INSTITUTION IS 'Type of financial instution.  Used for Securities form only.  See SAR form for values.  This column contains letters only ''a'' through ''z''.'
;


COMMENT ON COLUMN AMLCTR.INSTITUTION.CONTACT_LNAME IS 'Contact last name'
;


COMMENT ON COLUMN AMLCTR.INSTITUTION.CONTACT_FNAME IS 'Contact first name'
;


COMMENT ON COLUMN AMLCTR.INSTITUTION.CONTACT_MI IS 'Contact middle initial'
;


COMMENT ON COLUMN AMLCTR.INSTITUTION.CONTACT_TITLE IS 'Contact title'
;


COMMENT ON COLUMN AMLCTR.INSTITUTION.CONTACT_WORK_PHONE IS 'Contact telephone number'
;


COMMENT ON COLUMN AMLCTR.INSTITUTION.TRANSMITTER_CONTROL_CODE IS 'This is the code assigned by the Detroit computing center.  This code is also entered on Form 4804 (for tape or cartridge).'
;




CREATE TABLE AMLCTR.INSTRUMENT_TYPE_CODES
(
	INST_TYPE  CHAR(1)  NOT NULL ,
	SAR_TYPE  CHAR(2)  NOT NULL ,
	DESCRIPTION  VARCHAR(40)  NOT NULL 
)
PRIMARY INDEX ( INST_TYPE )
;


COMMENT ON TABLE AMLCTR.INSTRUMENT_TYPE_CODES IS 'Financial instrument type codes'
;


COMMENT ON COLUMN AMLCTR.INSTRUMENT_TYPE_CODES.INST_TYPE IS 'Financial instrument type codes'
;


COMMENT ON COLUMN AMLCTR.INSTRUMENT_TYPE_CODES.SAR_TYPE IS 'Type of SAR (i.e. banking, brokerage)'
;


COMMENT ON COLUMN AMLCTR.INSTRUMENT_TYPE_CODES.DESCRIPTION IS 'Long text description of financial instrument'
;


ALTER TABLE AMLCTR.INSTRUMENT_TYPE_CODES
	ADD CONSTRAINT  XPKE_21 PRIMARY KEY (INST_TYPE,SAR_TYPE)
;


CREATE TABLE AMLCTR.REGULATOR_CODES
(
	PRIMARY_REGULATOR  CHAR(1)  NOT NULL ,
	SAR_TYPE  CHAR(2)  NOT NULL ,
	DESCRIPTION  VARCHAR(40)  NOT NULL 
)
PRIMARY INDEX ( SAR_TYPE )
;


COMMENT ON TABLE AMLCTR.REGULATOR_CODES IS 'Financial regulator codes'
;


COMMENT ON COLUMN AMLCTR.REGULATOR_CODES.PRIMARY_REGULATOR IS 'Primary government regulator code'
;


COMMENT ON COLUMN AMLCTR.REGULATOR_CODES.SAR_TYPE IS 'Type of SAR (i.e. banking, brokerage)'
;


COMMENT ON COLUMN AMLCTR.REGULATOR_CODES.DESCRIPTION IS 'Long text description of the primary government regulator'
;


ALTER TABLE AMLCTR.REGULATOR_CODES
	ADD CONSTRAINT  XPKE_23 PRIMARY KEY (PRIMARY_REGULATOR,SAR_TYPE)
;


CREATE TABLE AMLCTR.RELATIONSHIP_CODES
(
	RELATIONSHIP_CODE  CHAR(2)  NOT NULL ,
	SAR_TYPE  CHAR(2)  NOT NULL ,
	DESCRIPTION  VARCHAR(40)  
)
PRIMARY INDEX ( RELATIONSHIP_CODE )
;


COMMENT ON TABLE AMLCTR.RELATIONSHIP_CODES IS 'Code table for relationship to financial institution codes.'
;


COMMENT ON COLUMN AMLCTR.RELATIONSHIP_CODES.RELATIONSHIP_CODE IS 'Subject''s relationship to the financial institution'
;


COMMENT ON COLUMN AMLCTR.RELATIONSHIP_CODES.SAR_TYPE IS 'Type of SAR (i.e. banking, brokerage)'
;


COMMENT ON COLUMN AMLCTR.RELATIONSHIP_CODES.DESCRIPTION IS 'Long text description of the relationship'
;


ALTER TABLE AMLCTR.RELATIONSHIP_CODES
	ADD CONSTRAINT  XPKE_17 PRIMARY KEY (RELATIONSHIP_CODE,SAR_TYPE)
;


CREATE TABLE AMLCTR.SAR_ALERTS
(
	SAR_ID  NUMERIC(15,0)  NOT NULL ,
	ALERT_ID  NUMERIC(15,0)  NOT NULL ,
	SEGMENT_ID  VARCHAR(128)  NOT NULL  DEFAULT user,
	PRIMARY KEY (SAR_ID,ALERT_ID,SEGMENT_ID)
)
;


COMMENT ON TABLE AMLCTR.SAR_ALERTS IS 'Stores related alert IDs.  SARs may be created from one to many alerts.'
;


COMMENT ON COLUMN AMLCTR.SAR_ALERTS.SAR_ID IS 'System generated primary key for SAR'
;


COMMENT ON COLUMN AMLCTR.SAR_ALERTS.ALERT_ID IS 'System generated primary key for an alert.  Each SAR must have one to many alerts.
'
;


CREATE TABLE AMLCTR.SAR_CNTL
(
	SAR_ID  NUMERIC(15,0)  NOT NULL ,
	SEGMENT_ID  VARCHAR(128)  NOT NULL  DEFAULT user,
	SAR_TYPE  CHAR(2)  NOT NULL ,
	SAR_DESCRIPTION  VARCHAR(60)  ,
	SAR_STATUS  CHAR(2)  NOT NULL ,
	CORRECTION  CHAR(1)  ,
	NUMBER_SUSPECTS  NUMERIC(8,0)  ,
	DATE_FILED TIMESTAMP  ,
	CREATE_USER  VARCHAR(35)  ,
	CREATE_DATE  TIMESTAMP  ,
	UPDATE_DATE  TIMESTAMP,
	UPDATE_ID  VARCHAR(35)  ,
	ORIGINAL_SAR_ID  NUMERIC(15)  ,
	ACTIVITY_TYPE_CODE  CHAR(3),
	PRIMARY KEY ( SAR_ID, SEGMENT_ID )
)
;


COMMENT ON TABLE AMLCTR.SAR_CNTL IS 'Primary control table for SAR component of the Knowledge Center data model.'
;


COMMENT ON COLUMN AMLCTR.SAR_CNTL.SAR_ID IS 'System generated primary key for SAR'
;


COMMENT ON COLUMN AMLCTR.SAR_CNTL.SAR_TYPE IS 'Type of SAR (i.e. banking, brokerage)
'
;


COMMENT ON COLUMN AMLCTR.SAR_CNTL.SAR_DESCRIPTION IS 'Text description of SAR'
;


COMMENT ON COLUMN AMLCTR.SAR_CNTL.SAR_STATUS IS 'Status of the SAR (i.e. open, closed, filed)'
;


COMMENT ON COLUMN AMLCTR.SAR_CNTL.CORRECTION IS 'Corrected SAR inidicator'
;


COMMENT ON COLUMN AMLCTR.SAR_CNTL.NUMBER_SUSPECTS IS 'Total count of suspects for this SAR'
;


COMMENT ON COLUMN AMLCTR.SAR_CNTL.DATE_FILED IS 'Date SAR is filed to FINCEN'
;


COMMENT ON COLUMN AMLCTR.SAR_CNTL.CREATE_USER IS 'ID of user creating SAR'
;


COMMENT ON COLUMN AMLCTR.SAR_CNTL.CREATE_DATE IS 'Date SAR was created'
;


COMMENT ON COLUMN AMLCTR.SAR_CNTL.UPDATE_DATE IS 'Date the SAR was last updated'
;


COMMENT ON COLUMN AMLCTR.SAR_CNTL.UPDATE_ID IS 'ID of user last updating  SAR'
;


COMMENT ON COLUMN AMLCTR.SAR_CNTL.ORIGINAL_SAR_ID IS 'Refers to the original report (SAR) that this report corrects.'
;


COMMENT ON COLUMN AMLCTR.SAR_CNTL.ACTIVITY_TYPE_CODE IS 'Type of suspected activity being reported.

TER - Terror Financing
MON - Money Laundering
'
;


CREATE TABLE AMLCTR.SAR_CONTACT
(
	SAR_ID  NUMERIC(15,0)  NOT NULL ,
	CONTACT_SEQ  NUMERIC(15,0)  NOT NULL ,
	LNAME  VARCHAR(20)  ,
	FNAME  VARCHAR(20)  ,
	MI  CHAR(1)  ,
	CONTACT_TITLE  VARCHAR(25)  ,
	WORK_PHONE  CHAR(10)  ,
	DATE_SUBMIT TIMESTAMP  ,
	AGENCY  VARCHAR(35)  ,
	UPDATE_DATE TIMESTAMP  ,
	UPDATE_ID  VARCHAR(35)  ,
	SEGMENT_ID  VARCHAR(128)  NOT NULL  DEFAULT user,
	CONSTRAINT  XPKE_10 PRIMARY KEY (SAR_ID,CONTACT_SEQ,SEGMENT_ID)
)
;


COMMENT ON TABLE AMLCTR.SAR_CONTACT IS 'SAR_CONTACT stores the contact information for the person(s) completing the SAR or other designated individuals.'
;


COMMENT ON COLUMN AMLCTR.SAR_CONTACT.SAR_ID IS 'System generated primary key for SAR'
;


COMMENT ON COLUMN AMLCTR.SAR_CONTACT.CONTACT_SEQ IS 'System generated sequence number'
;


COMMENT ON COLUMN AMLCTR.SAR_CONTACT.LNAME IS 'Contact last name'
;


COMMENT ON COLUMN AMLCTR.SAR_CONTACT.FNAME IS 'Contact first name'
;


COMMENT ON COLUMN AMLCTR.SAR_CONTACT.MI IS 'Contact middle initial'
;


COMMENT ON COLUMN AMLCTR.SAR_CONTACT.CONTACT_TITLE IS 'Contact title or position'
;


COMMENT ON COLUMN AMLCTR.SAR_CONTACT.WORK_PHONE IS 'Contact work phone number'
;


COMMENT ON COLUMN AMLCTR.SAR_CONTACT.DATE_SUBMIT IS 'Date report prepared'
;


COMMENT ON COLUMN AMLCTR.SAR_CONTACT.AGENCY IS 'Agency (if not filed by financial institution)'
;


COMMENT ON COLUMN AMLCTR.SAR_CONTACT.UPDATE_DATE IS 'Date the SAR was last updated'
;


COMMENT ON COLUMN AMLCTR.SAR_CONTACT.UPDATE_ID IS 'ID of user last updating SAR'
;


CREATE TABLE AMLCTR.SAR_INFO
(
	SAR_ID  NUMERIC(15,0)  NOT NULL ,
	SEGMENT_ID  VARCHAR(128)  NOT NULL  DEFAULT user,
	ACCT_NBR1  VARCHAR(22)  ,
	ACCT1_ACTIVE  CHAR(1)  ,
	ACCT_NBR2  VARCHAR(22)  ,
	ACCT2_ACTIVE  CHAR(1)  ,
	ACCT_NBR3  VARCHAR(22)  ,
	ACCT3_ACTIVE  CHAR(1)  ,
	ACCT_NBR4  VARCHAR(22)  ,
	ACCT4_ACTIVE  CHAR(1)  ,
	FROM_DATE TIMESTAMP  ,
	TO_DATE TIMESTAMP  ,
	AMOUNT  NUMERIC(15,2)  ,
	AMT_LOSS  DECIMAL(15,2)  ,
	AMT_RECOVERED  DECIMAL(15,2)  ,
	MATERIAL_IMPACT  CHAR(1)  ,
	BONDING_NOTIFY  CHAR(1)  ,
	INST_TYPE  VARCHAR(25)  ,
	CUSIP_1  CHAR(12)  ,
	CUSIP_2  CHAR(12)  ,
	CUSIP_3  CHAR(12)  ,
	CUSIP_4  CHAR(12)  ,
	CUSIP_5  CHAR(12)  ,
	CUSIP_6  CHAR(12)  ,
	COMMODITY_TYPE  VARCHAR(20)  ,
	INSTRUMENT_DESC  VARCHAR(20)  ,
	MARKET_TRADED  CHAR(4)  ,
	ACTIVITY_TYPE  VARCHAR(20)  ,
	ACTIVITY_OTHER  VARCHAR(40)  ,
	ENFORCEMENT  VARCHAR(18)  ,
	OTH_ENFORCEMENT  VARCHAR(35)  ,
	ENF_CONTACT1  VARCHAR(35)  ,
	ENF_PHONE1  VARCHAR(10)  ,
	ENF_CONTACT2  VARCHAR(35)  ,
	ENF_PHONE2  VARCHAR(10)  ,
	ENF_DATE TIMESTAMP  ,
	UPDATE_DATE TIMESTAMP  ,
	UPDATE_ID  VARCHAR(35)  ,
	PRIMARY KEY ( SAR_ID, SEGMENT_ID )
)
;


COMMENT ON TABLE AMLCTR.SAR_INFO IS 'SAR_INFO contains the basic suspicious activity information required to complete a SAR.  For example, Dollar amount and account information.'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.SAR_ID IS 'System generated primary key for SAR'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.ACCT_NBR1 IS 'Account number affected'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.ACCT1_ACTIVE IS 'Account open or closed'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.ACCT_NBR2 IS 'Account number affected 
'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.ACCT2_ACTIVE IS 'Account open or closed'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.ACCT_NBR3 IS 'Account number affected'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.ACCT3_ACTIVE IS 'Account open or closed'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.ACCT_NBR4 IS 'Account number affected'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.ACCT4_ACTIVE IS 'Account open or closed'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.FROM_DATE IS 'Beginning date of suspicious activity (Part III F9022 and Part 2 FIN101)'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.TO_DATE IS 'Ending date of suspicious activity (Part III F9022 and Part 2 FIN101)'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.AMOUNT IS 'Total dollar amount involved in suspicious activity'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.AMT_LOSS IS 'Amout of loss prior to recovery'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.AMT_RECOVERED IS 'Total dollar amount recovered'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.MATERIAL_IMPACT IS 'Has the suspicious activity had a material impact on, or otherwise affected the financial soundness of the institutions  (Yes or No).'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.BONDING_NOTIFY IS 'Has the institution''s bonding company been notified'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.INST_TYPE IS 'FIN101 Only.  Instrrument type (multiple responses).'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.CUSIP_1 IS 'FIN101 Only.  CUSIP Number'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.CUSIP_2 IS 'FIN101 Only.  CUSIP Number'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.CUSIP_3 IS 'FIN101 Only.  CUSIP Number'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.CUSIP_4 IS 'FIN101 Only.  CUSIP Number'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.CUSIP_5 IS 'FIN101 Only.  CUSIP Number'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.CUSIP_6 IS 'FIN101 Only.  CUSIP Number'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.COMMODITY_TYPE IS 'FIN101 Only, Part II,  Field 23.  Commodity type description.'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.INSTRUMENT_DESC IS 'FIN101 Only, Part II,  Field 23.  Instrument description'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.MARKET_TRADED IS 'FIN101 Only, Part II,  Field 23.  Market where traded.'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.ACTIVITY_TYPE IS 'Type of suspicious activity (FIN101, field 30 and F9022, field 35).'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.ACTIVITY_OTHER IS 'Other type of suspicious activity not listed (FIN101, field 30 and F9022, field 35).'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.ENFORCEMENT IS 'Has any law enforcement agency already been advised by telephone, written communication, or otherwise?'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.OTH_ENFORCEMENT IS 'Other law enforcement agency or agency name.'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.ENF_CONTACT1 IS 'Name of enforcement individual contacted.'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.ENF_PHONE1 IS 'Law enforcement phone number'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.ENF_CONTACT2 IS 'Name of enforcement individual contacted.'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.ENF_PHONE2 IS 'Law enforcement phone number'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.ENF_DATE IS 'Date enforcement agency contacted.'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.UPDATE_DATE IS 'Date the SAR was last updated'
;


COMMENT ON COLUMN AMLCTR.SAR_INFO.UPDATE_ID IS 'ID of user last updating  SAR'
;


CREATE TABLE AMLCTR.SAR_INSTITUTION
(
	SAR_ID  NUMERIC(15,0)  NOT NULL ,
	INSTITUTION_SEQ  NUMERIC(15,0)  NOT NULL ,
	SEGMENT_ID  VARCHAR(128)  NOT NULL  DEFAULT user,
	NAME  VARCHAR(35)  ,
	EIN  CHAR(9)  ,
	ADDRESS  VARCHAR(35)  ,
	CITY  VARCHAR(25)  ,
	STATE  CHAR(2)  ,
	ZIP  CHAR(9)  ,
	DATE_CLOSED TIMESTAMP  ,
	PRIMARY_REGULATOR  CHAR(1)  ,
	BRANCH_ADDRESS  VARCHAR(35)  ,
	BRANCH_CITY  VARCHAR(35)  ,
	BRANCH_STATE  CHAR(2)  ,
	BRANCH_ZIP  CHAR(9)  ,
	BRANCH_CODE  CHAR(7)  ,
	MULTIPLE_BRANCHES  CHAR(1)  ,
	CEN_REG_NBR  CHAR(11)  ,
	SEC_ID  CHAR(9)  ,
	NFA_ID  CHAR(8)  ,
	RPT_COORD  CHAR(1)  ,
	TYPE_INST  VARCHAR(27)  ,
	UPDATE_DATE TIMESTAMP  ,
	UPDATE_ID  VARCHAR(35)  ,
	PRIMARY KEY (SAR_ID,INSTITUTION_SEQ,SEGMENT_ID)
)
;


COMMENT ON TABLE AMLCTR.SAR_INSTITUTION IS 'SAR_INSTITUTION contains financial institution information (i.e. address and branch information) needed to file a SAR.'
;


COMMENT ON COLUMN AMLCTR.SAR_INSTITUTION.SAR_ID IS 'System generated primary key for SAR'
;


COMMENT ON COLUMN AMLCTR.SAR_INSTITUTION.INSTITUTION_SEQ IS 'System generated sequence number for institution information Part 1 of SAR form F9022 and Part 4 of FIN101
'
;


COMMENT ON COLUMN AMLCTR.SAR_INSTITUTION.NAME IS 'Name of Financial Institution'
;


COMMENT ON COLUMN AMLCTR.SAR_INSTITUTION.EIN IS 'Employer identification number or tax payer identifcation number if sole proprietorship'
;


COMMENT ON COLUMN AMLCTR.SAR_INSTITUTION.ADDRESS IS 'Address of Financial Institution'
;


COMMENT ON COLUMN AMLCTR.SAR_INSTITUTION.CITY IS 'City'
;


COMMENT ON COLUMN AMLCTR.SAR_INSTITUTION.STATE IS 'State'
;


COMMENT ON COLUMN AMLCTR.SAR_INSTITUTION.ZIP IS 'ZIP Code'
;


COMMENT ON COLUMN AMLCTR.SAR_INSTITUTION.DATE_CLOSED IS 'If Institution closed, date closed'
;


COMMENT ON COLUMN AMLCTR.SAR_INSTITUTION.PRIMARY_REGULATOR IS 'Primary Federal Regulator'
;


COMMENT ON COLUMN AMLCTR.SAR_INSTITUTION.BRANCH_ADDRESS IS 'Address of Branch Offices(s) where activity occurred'
;


COMMENT ON COLUMN AMLCTR.SAR_INSTITUTION.BRANCH_CITY IS 'City of Branch'
;


COMMENT ON COLUMN AMLCTR.SAR_INSTITUTION.BRANCH_STATE IS 'State of Branch'
;


COMMENT ON COLUMN AMLCTR.SAR_INSTITUTION.BRANCH_ZIP IS 'ZIP Code of Branch'
;


COMMENT ON COLUMN AMLCTR.SAR_INSTITUTION.BRANCH_CODE IS 'Institution''s branch code number.  SAR defines it as a 7 byte field.'
;


COMMENT ON COLUMN AMLCTR.SAR_INSTITUTION.MULTIPLE_BRANCHES IS 'Multiple branch indicator.  Location for multiple branches is supplied in narrative,  Part V,'
;


COMMENT ON COLUMN AMLCTR.SAR_INSTITUTION.CEN_REG_NBR IS 'FIN101 ONLY. Central Registration Depository Number.'
;


COMMENT ON COLUMN AMLCTR.SAR_INSTITUTION.SEC_ID IS 'FIN101 ONLY.  SEC ID Number'
;


COMMENT ON COLUMN AMLCTR.SAR_INSTITUTION.NFA_ID IS 'FIN101 ONLY.  National Futures Association ID Number.'
;


COMMENT ON COLUMN AMLCTR.SAR_INSTITUTION.RPT_COORD IS 'FIN101 ONLY.  Has this reporting individual/entity coordinated this report with another reporting individual/entity.  If "Yes" then provide details in Part VI.'
;


COMMENT ON COLUMN AMLCTR.SAR_INSTITUTION.TYPE_INST IS 'FIN101 ONLY.  Type of Institution.

Used for Securities form only.  See SAR form for values.  This column contains letters only ''a'' through ''z''.'
;


COMMENT ON COLUMN AMLCTR.SAR_INSTITUTION.UPDATE_DATE IS 'Date the SAR was last updated'
;


COMMENT ON COLUMN AMLCTR.SAR_INSTITUTION.UPDATE_ID IS 'ID of user last updating  SAR'
;






CREATE TABLE AMLCTR.SAR_NAMES
(
	SAR_ID  NUMERIC(15,0)  NOT NULL ,
	NAME_SEQ  NUMERIC(15,0)  NOT NULL ,
	SEGMENT_ID  VARCHAR(128)  NOT NULL  DEFAULT user,
	LNAME  VARCHAR(20)  ,
	FNAME  VARCHAR(20)  ,
	MI  CHAR(1)  ,
	AKA  VARCHAR(35)  ,
	SSN_EIN  CHAR(9)  ,
	DOB  TIMESTAMP  ,
	OCCUPATION  VARCHAR(30)  ,
	ADMISSION_CONFESSION  CHAR(1)  ,
	ADDRESS  VARCHAR(35)  ,
	CITY  VARCHAR(25)  ,
	STATE  CHAR(2)  ,
	ZIP  CHAR(9)  ,
	COUNTRY  CHAR(2)  ,
	EMAIL  VARCHAR(60)  ,
	RELATIONSHIP_CODE  CHAR(4)  ,
	RELATIONSHIP_OTHER  VARCHAR(40)  ,
	INSIDE_RELATIONSHIP  CHAR(2)  ,
	TERMINATION_DATE  TIMESTAMP  ,
	GOVT_ID  CHAR(1)  ,
	ID_OTHER  VARCHAR(40)  ,
	ID_NBR  VARCHAR(22)  ,
	ID_ORIGIN  CHAR(2)  ,
	WORK_PHONE  CHAR(10)  ,
	HOME_PHONE  CHAR(10)  ,
	ASSOCIATED  CHAR(1)  ,
	UPDATE_DATE  TIMESTAMP  ,
	UPDATE_ID  VARCHAR(35)  ,
	PARTY_TAX_ID  VARCHAR(50)  ,
	CITIZENSHIP_COUNTRY_CODE  CHAR(3)  ,
	STREET_ADDRESS_TEXT  VARCHAR(255)  ,
	MAILING_ADDRESS_TEXT  VARCHAR(255)  ,
	INTERNAL_RELATIONSHIP_TEXT  VARCHAR(1024)  ,
	EXTERNAL_RELATIONSHIP_TEXT  VARCHAR(1024)  ,
	PRIMARY KEY (SAR_ID,NAME_SEQ,SEGMENT_ID)
)
;


COMMENT ON TABLE AMLCTR.SAR_NAMES IS 'SAR_NAMES holds names and related information for all suspects associated with a single SAR.  Multiple names are actully reported in the Narative section of the SAR when filed.'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.SAR_ID IS 'System generated primary key for SAR'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.NAME_SEQ IS 'System generated sequence number'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.LNAME IS 'Individual''s last name or entity''s full name'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.FNAME IS 'First Name'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.MI IS 'Middle name'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.AKA IS 'Also known as or doing business as'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.SSN_EIN IS 'Social security number for an individual or employer identification number for an entity.'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.DOB IS 'Date of birth'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.OCCUPATION IS 'Usual occupation or type of  business'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.ADMISSION_CONFESSION IS 'F9022 field 28.  Yes/No subject has confessed or admitted guilt.'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.ADDRESS IS 'Subject''s street address'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.CITY IS 'Subject''s city'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.STATE IS 'Subject''s state'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.ZIP IS 'Subject''s ZIP Code'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.COUNTRY IS 'Subject''s country of residence'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.EMAIL IS 'Subject''s email address'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.RELATIONSHIP_CODE IS 'Subject''s relationship to the financial institution'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.RELATIONSHIP_OTHER IS 'Other non-standard relationships to the financial institution'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.INSIDE_RELATIONSHIP IS 'Is the relationship an insider relationship?  This is a 2 byte field that holds the YES/NO and "if yes specify" responses.'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.TERMINATION_DATE IS 'Date of suspension, termination, or resignation.'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.GOVT_ID IS 'Forms of identification for suspect'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.ID_OTHER IS 'Other ID not listed.'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.ID_NBR IS 'Suspect''s identification number'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.ID_ORIGIN IS 'Suspect''s ID''s issuing authority'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.WORK_PHONE IS 'Suspect''s work phone number'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.HOME_PHONE IS 'Suspect''s home phone number'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.ASSOCIATED IS 'Is individual/business associated/affiliated with the reporting institution? (YES/NO)'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.UPDATE_DATE IS 'ID of user last updating  SAR'
;


COMMENT ON COLUMN AMLCTR.SAR_NAMES.UPDATE_ID IS 'ID of user last updating SAR'
;


CREATE TABLE AMLCTR.SAR_NARATIVE
(
	SAR_ID  NUMERIC(15,0)  NOT NULL ,
	NARATIVE_SEQ  NUMERIC(15,0)  NOT NULL ,
	SEGMENT_ID  VARCHAR(128)  NOT NULL  DEFAULT user,
	NARATIVE  VARCHAR(32000)  NOT NULL ,
	UPDATE_DATE TIMESTAMP  ,
	UPDATE_ID  VARCHAR(35) ,
	PRIMARY KEY (SAR_ID,NARATIVE_SEQ,SEGMENT_ID)
)
;


COMMENT ON TABLE AMLCTR.SAR_NARATIVE IS 'SAR_NARATIVE stores all related text descriptions or other written statements for the SAR.'
;


COMMENT ON COLUMN AMLCTR.SAR_NARATIVE.SAR_ID IS 'System generated primary key for SAR'
;


COMMENT ON COLUMN AMLCTR.SAR_NARATIVE.NARATIVE_SEQ IS 'System generated sequence number'
;


COMMENT ON COLUMN AMLCTR.SAR_NARATIVE.NARATIVE IS 'Part VI.  This field contains the text descriptions supporting the SAR.'
;


COMMENT ON COLUMN AMLCTR.SAR_NARATIVE.UPDATE_DATE IS 'Date the SAR was last updated'
;


COMMENT ON COLUMN AMLCTR.SAR_NARATIVE.UPDATE_ID IS 'ID of user last updating SAR'
;


CREATE TABLE AMLCTR.SAR_STATUS_CODES
(
	SAR_STATUS  CHAR(2)  NOT NULL ,
	SAR_STATUS_DSCR  VARCHAR(45)  NOT NULL ,
	PRIMARY KEY ( SAR_STATUS )
)
;


COMMENT ON TABLE AMLCTR.SAR_STATUS_CODES IS 'SAR Status Code Table'
;


COMMENT ON COLUMN AMLCTR.SAR_STATUS_CODES.SAR_STATUS IS 'Status codes (i.e. open, closed, filed)'
;


COMMENT ON COLUMN AMLCTR.SAR_STATUS_CODES.SAR_STATUS_DSCR IS 'Text description of status code'
;




CREATE TABLE AMLCTR.SAR_TRANSACTION
(
	SAR_ID  NUMERIC(15,0)  NOT NULL ,
	TRANSACTION_SEQ  NUMERIC(15)  NOT NULL ,
	SEGMENT_ID  VARCHAR(128)  NOT NULL  DEFAULT user,
	TRANSACTION_TYPE_DESC  VARCHAR(35)  ,
	TRANSACTION_DATE_DESC  VARCHAR(35)  ,
	BRANCH_NUMBER  VARCHAR(25)  ,
	BRANCH_NAME  VARCHAR(35)  ,
	CURRENCY_AMT_IN_TXN_CCY  VARCHAR(35)  ,
	TRANSACTION_CURRENCY_CODE  CHAR(3)  ,
	PURPOSE_DESC  VARCHAR(1024)  ,
	SOURCE_OF_FUNDS_DESC  VARCHAR(1024)  ,
	ACCOUNT_NUMBER  VARCHAR(50)  ,
	COMMENT_TEXT  VARCHAR(1024)  ,
	PRIMARY KEY (SAR_ID,TRANSACTION_SEQ,SEGMENT_ID)
) 
;


COMMENT ON COLUMN AMLCTR.SAR_TRANSACTION.SAR_ID IS 'System generated primary key for SAR'
;






CREATE TABLE AMLCTR.SAR_TYPE_CODES
(
	SAR_TYPE  CHAR(2)  NOT NULL ,
	SAR_TYPE_DSCR  VARCHAR(45)  NOT NULL ,
	SAR_TYPE_SHORT_DSCR  VARCHAR(35)  ,
	ACTIVE_FLAG  CHAR(1),
	PRIMARY KEY ( SAR_TYPE )
)
;


COMMENT ON TABLE AMLCTR.SAR_TYPE_CODES IS 'SAR Type Code Table.'
;


COMMENT ON COLUMN AMLCTR.SAR_TYPE_CODES.SAR_TYPE IS 'Type of SAR (i.e. banking, brokerage)'
;


COMMENT ON COLUMN AMLCTR.SAR_TYPE_CODES.SAR_TYPE_DSCR IS 'Text description of SAR type'
;


COMMENT ON COLUMN AMLCTR.SAR_TYPE_CODES.SAR_TYPE_SHORT_DSCR IS 'Short version of description'
;


COMMENT ON COLUMN AMLCTR.SAR_TYPE_CODES.ACTIVE_FLAG IS 'Active indicator.  Some SAR types may not be available for all users or lines of business.'
;

CREATE TABLE AMLCTR.STATE_CODES
(
	STATE  CHAR(2)  NOT NULL ,
	COUNTRY  CHAR(2)  NOT NULL ,
	STATE_NAME  VARCHAR(40)  NOT NULL ,
	SAR_TYPE  CHAR(2) ,
	PRIMARY KEY (STATE,COUNTRY)
)
;


COMMENT ON TABLE AMLCTR.STATE_CODES IS 'Code table for storing state codes.'
;


COMMENT ON COLUMN AMLCTR.STATE_CODES.STATE IS 'State abbreviation'
;


COMMENT ON COLUMN AMLCTR.STATE_CODES.COUNTRY IS 'Country code'
;


COMMENT ON COLUMN AMLCTR.STATE_CODES.STATE_NAME IS 'Formal state name'
;


ALTER TABLE AMLCTR.BATCH_SEQ
	ADD CONSTRAINT  R_10  FOREIGN KEY (SAR_ID,SEGMENT_ID) REFERENCES AMLCTR.SAR_INFO(SAR_ID,SEGMENT_ID)
;


ALTER TABLE AMLCTR.BRANCH
	ADD CONSTRAINT  R_11  FOREIGN KEY (INSTITUTION_ID,SEGMENT_ID) REFERENCES AMLCTR.INSTITUTION(INSTITUTION_ID,SEGMENT_ID)
;


ALTER TABLE AMLCTR.SAR_ALERTS
	ADD CONSTRAINT  R_3  FOREIGN KEY (SAR_ID,SEGMENT_ID) REFERENCES AMLCTR.SAR_CNTL(SAR_ID,SEGMENT_ID)
;


ALTER TABLE AMLCTR.SAR_CNTL
	ADD CONSTRAINT  R_4  FOREIGN KEY (SAR_TYPE) REFERENCES AMLCTR.SAR_TYPE_CODES(SAR_TYPE)
;


ALTER TABLE AMLCTR.SAR_CNTL
	ADD CONSTRAINT  R_5  FOREIGN KEY (SAR_STATUS) REFERENCES AMLCTR.SAR_STATUS_CODES(SAR_STATUS)
;


ALTER TABLE AMLCTR.SAR_CONTACT
	ADD CONSTRAINT  R_9  FOREIGN KEY (SAR_ID,SEGMENT_ID) REFERENCES AMLCTR.SAR_INFO(SAR_ID,SEGMENT_ID)
;


ALTER TABLE AMLCTR.SAR_INFO
	ADD CONSTRAINT  R_2  FOREIGN KEY (SAR_ID,SEGMENT_ID) REFERENCES AMLCTR.SAR_CNTL(SAR_ID,SEGMENT_ID)
;


ALTER TABLE AMLCTR.SAR_INSTITUTION
	ADD CONSTRAINT  R_8  FOREIGN KEY (SAR_ID,SEGMENT_ID) REFERENCES AMLCTR.SAR_INFO(SAR_ID,SEGMENT_ID)
;


ALTER TABLE AMLCTR.SAR_NAMES
	ADD CONSTRAINT  R_6  FOREIGN KEY (SAR_ID,SEGMENT_ID) REFERENCES AMLCTR.SAR_INFO(SAR_ID,SEGMENT_ID)
;


ALTER TABLE AMLCTR.SAR_NARATIVE
	ADD CONSTRAINT  R_7  FOREIGN KEY (SAR_ID,SEGMENT_ID) REFERENCES AMLCTR.SAR_INFO(SAR_ID,SEGMENT_ID)
;


ALTER TABLE AMLCTR.SAR_TRANSACTION
	ADD CONSTRAINT  R_12  FOREIGN KEY (SAR_ID,SEGMENT_ID) REFERENCES AMLCTR.SAR_INFO(SAR_ID,SEGMENT_ID)
;



create view BANK1KCTR.ACTIVITY_TYPE_CODES as locking row for access select * from AMLCTR.ACTIVITY_TYPE_CODES;
create view BANK1KCTR.BATCH_SEQ as locking row for access select * from AMLCTR.BATCH_SEQ where segment_id='BANK1KCTR';
create view BANK1KCTR.BRANCH as locking row for access select * from AMLCTR.BRANCH where segment_id='BANK1KCTR';
create view BANK1KCTR.COUNTRY_CODES as locking row for access select * from AMLCTR.COUNTRY_CODES;
create view BANK1KCTR.ENFORCEMENT_CODES as locking row for access select * from AMLCTR.ENFORCEMENT_CODES;
create view BANK1KCTR.GOVT_ID_CODES as locking row for access select * from AMLCTR.GOVT_ID_CODES;
create view BANK1KCTR.INSIDE_RELATIONSHIP_CODES as locking row for access select * from AMLCTR.INSIDE_RELATIONSHIP_CODES;
create view BANK1KCTR.INSTITUTION as locking row for access select * from AMLCTR.INSTITUTION where segment_id='BANK1KCTR';
create view BANK1KCTR.INSTRUMENT_TYPE_CODES as locking row for access select * from AMLCTR.INSTRUMENT_TYPE_CODES;
create view BANK1KCTR.REGULATOR_CODES as locking row for access select * from AMLCTR.REGULATOR_CODES;
create view BANK1KCTR.RELATIONSHIP_CODES as locking row for access select * from AMLCTR.RELATIONSHIP_CODES;
create view BANK1KCTR.SAR_ALERTS as locking row for access select * from AMLCTR.SAR_ALERTS where segment_id='BANK1KCTR';
create view BANK1KCTR.SAR_CNTL as locking row for access select * from AMLCTR.SAR_CNTL where segment_id='BANK1KCTR';
create view BANK1KCTR.SAR_CONTACT as locking row for access select * from AMLCTR.SAR_CONTACT where segment_id='BANK1KCTR';
create view BANK1KCTR.SAR_INFO as locking row for access select * from AMLCTR.SAR_INFO where segment_id='BANK1KCTR';
create view BANK1KCTR.SAR_INSTITUTION as locking row for access select * from AMLCTR.SAR_INSTITUTION where segment_id='BANK1KCTR';
create view BANK1KCTR.SAR_NAMES as locking row for access select * from AMLCTR.SAR_NAMES where segment_id='BANK1KCTR';
create view BANK1KCTR.SAR_NARATIVE as locking row for access select * from AMLCTR.SAR_NARATIVE where segment_id='BANK1KCTR';
create view BANK1KCTR.SAR_STATUS_CODES as locking row for access select * from AMLCTR.SAR_STATUS_CODES;
create view BANK1KCTR.SAR_TRANSACTION as locking row for access select * from AMLCTR.SAR_TRANSACTION where segment_id='BANK1KCTR';
create view BANK1KCTR.SAR_TYPE_CODES as locking row for access select * from AMLCTR.SAR_TYPE_CODES;
create view BANK1KCTR.STATE_CODES as locking row for access select * from AMLCTR.STATE_CODES;

create view BANK2KCTR.ACTIVITY_TYPE_CODES as locking row for access select * from AMLCTR.ACTIVITY_TYPE_CODES;
create view BANK2KCTR.BATCH_SEQ as locking row for access select * from AMLCTR.BATCH_SEQ where segment_id='BANK2KCTR';
create view BANK2KCTR.BRANCH as locking row for access select * from AMLCTR.BRANCH where segment_id='BANK2KCTR';
create view BANK2KCTR.COUNTRY_CODES as locking row for access select * from AMLCTR.COUNTRY_CODES;
create view BANK2KCTR.ENFORCEMENT_CODES as locking row for access select * from AMLCTR.ENFORCEMENT_CODES;
create view BANK2KCTR.GOVT_ID_CODES as locking row for access select * from AMLCTR.GOVT_ID_CODES;
create view BANK2KCTR.INSIDE_RELATIONSHIP_CODES as locking row for access select * from AMLCTR.INSIDE_RELATIONSHIP_CODES;
create view BANK2KCTR.INSTITUTION as locking row for access select * from AMLCTR.INSTITUTION where segment_id='BANK2KCTR';
create view BANK2KCTR.INSTRUMENT_TYPE_CODES as locking row for access select * from AMLCTR.INSTRUMENT_TYPE_CODES;
create view BANK2KCTR.REGULATOR_CODES as locking row for access select * from AMLCTR.REGULATOR_CODES;
create view BANK2KCTR.RELATIONSHIP_CODES as locking row for access select * from AMLCTR.RELATIONSHIP_CODES;
create view BANK2KCTR.SAR_ALERTS as locking row for access select * from AMLCTR.SAR_ALERTS where segment_id='BANK2KCTR';
create view BANK2KCTR.SAR_CNTL as locking row for access select * from AMLCTR.SAR_CNTL where segment_id='BANK2KCTR';
create view BANK2KCTR.SAR_CONTACT as locking row for access select * from AMLCTR.SAR_CONTACT where segment_id='BANK2KCTR';
create view BANK2KCTR.SAR_INFO as locking row for access select * from AMLCTR.SAR_INFO where segment_id='BANK2KCTR';
create view BANK2KCTR.SAR_INSTITUTION as locking row for access select * from AMLCTR.SAR_INSTITUTION where segment_id='BANK2KCTR';
create view BANK2KCTR.SAR_NAMES as locking row for access select * from AMLCTR.SAR_NAMES where segment_id='BANK2KCTR';
create view BANK2KCTR.SAR_NARATIVE as locking row for access select * from AMLCTR.SAR_NARATIVE where segment_id='BANK2KCTR';
create view BANK2KCTR.SAR_STATUS_CODES as locking row for access select * from AMLCTR.SAR_STATUS_CODES;
create view BANK2KCTR.SAR_TRANSACTION as locking row for access select * from AMLCTR.SAR_TRANSACTION where segment_id='BANK2KCTR';
create view BANK2KCTR.SAR_TYPE_CODES as locking row for access select * from AMLCTR.SAR_TYPE_CODES;
create view BANK2KCTR.STATE_CODES as locking row for access select * from AMLCTR.STATE_CODES;